<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-safehtml?lang_cible=pt
// ** ne pas modifier le fichier **

return [

	// S
	'safehtml_description' => 'Protecção dos fóruns contra os ataques do tipo cross-site scripting',
	'safehtml_slogan' => 'Protecção dos fóruns contra o cross-site scripting',
];
